# demcmc
Differential Emission Measure estimation using MCMC methods

[![codecov](https://codecov.io/gh/dstansby/demcmc/branch/main/graph/badge.svg?token=5LIRszKxGL)](https://codecov.io/gh/dstansby/demcmc)
[![Documentation Status](https://readthedocs.org/projects/demcmc/badge/?version=latest)](https://demcmc.readthedocs.io/en/latest/?badge=latest)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/dstansby/demcmc/main.svg)](https://results.pre-commit.ci/latest/github/dstansby/demcmc/main)

## Contributing

We love contributions! demcmc is open source, built on open source, and we're open to all types of contributions from anyone.

Contributing doesn't just mean writing code. You can help out by writing documentation, tests, or even giving feedback about the project (and yes - that includes giving feedback about the contribution process). Some of these contributions may be the most valuable to the project as a whole, because you're coming to the project with fresh eyes, so you can see the errors and assumptions that seasoned contributors have glossed over.
